@@ -9,7 +9,7 @@
 #' @family numeric metrics
 #' @family consistency metrics
 #' @family accuracy metrics
-#' @templateVar metric_fn ccc
+#' @templateVar fn ccc
 #' @template return
 #'
 #' @inheritParams rmse
@@ -51,19 +51,17 @@ ccc.data.frame <- function(data,
                            na_rm = TRUE,
                            case_weights = NULL,
                            ...) {
-
-  metric_summarizer(
-    metric_nm = "ccc",
-    metric_fn = ccc_vec,
+  numeric_metric_summarizer(
+    name = "ccc",
+    fn = ccc_vec,
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
     na_rm = na_rm,
     case_weights = !!enquo(case_weights),
     # Extra argument for ccc_impl()
-    metric_fn_options = list(bias = bias)
+    fn_options = list(bias = bias)
   )
-
 }
 
 #' @export
@@ -74,24 +72,25 @@ ccc_vec <- function(truth,
                     na_rm = TRUE,
                     case_weights = NULL,
                     ...) {
-  metric_vec_template(
-    metric_impl = ccc_impl,
-    truth = truth,
-    estimate = estimate,
-    na_rm = na_rm,
-    case_weights = case_weights,
-    cls = "numeric",
-    bias = bias
-  )
+  check_numeric_metric(truth, estimate, case_weights)
+
+  if (na_rm) {
+    result <- yardstick_remove_missing(truth, estimate, case_weights)
+
+    truth <- result$truth
+    estimate <- result$estimate
+    case_weights <- result$case_weights
+  } else if (yardstick_any_missing(truth, estimate, case_weights)) {
+    return(NA_real_)
+  }
+
+  ccc_impl(truth, estimate, bias, case_weights)
 }
 
 ccc_impl <- function(truth,
                      estimate,
-                     ...,
-                     bias = FALSE,
-                     case_weights = NULL) {
-  check_dots_empty()
-
+                     bias,
+                     case_weights) {
   case_weights <- vec_cast(case_weights, to = double())
 
   truth_mean <- yardstick_mean(truth, case_weights = case_weights)
@@ -117,7 +116,7 @@ ccc_impl <- function(truth,
   }
 
   numerator <- 2 * covariance
-  denominator <- truth_variance + estimate_variance + (truth_mean - estimate_mean) ^ 2
+  denominator <- truth_variance + estimate_variance + (truth_mean - estimate_mean)^2
 
   numerator / denominator
 }
