@@ -19,7 +19,7 @@
 #'
 #' @family numeric metrics
 #' @family accuracy metrics
-#' @templateVar metric_fn msd
+#' @templateVar fn msd
 #' @template return
 #'
 #' @inheritParams rmse
@@ -45,9 +45,9 @@ msd.data.frame <- function(data,
                            na_rm = TRUE,
                            case_weights = NULL,
                            ...) {
-  metric_summarizer(
-    metric_nm = "msd",
-    metric_fn = msd_vec,
+  numeric_metric_summarizer(
+    name = "msd",
+    fn = msd_vec,
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
@@ -63,17 +63,21 @@ msd_vec <- function(truth,
                     na_rm = TRUE,
                     case_weights = NULL,
                     ...) {
-  metric_vec_template(
-    metric_impl = msd_impl,
-    truth = truth,
-    estimate = estimate,
-    na_rm = na_rm,
-    case_weights = case_weights,
-    cls = "numeric"
-  )
+  check_numeric_metric(truth, estimate, case_weights)
+
+  if (na_rm) {
+    result <- yardstick_remove_missing(truth, estimate, case_weights)
+
+    truth <- result$truth
+    estimate <- result$estimate
+    case_weights <- result$case_weights
+  } else if (yardstick_any_missing(truth, estimate, case_weights)) {
+    return(NA_real_)
+  }
+
+  msd_impl(truth, estimate, case_weights)
 }
 
-msd_impl <- function(truth, estimate, ..., case_weights = NULL) {
-  check_dots_empty()
+msd_impl <- function(truth, estimate, case_weights) {
   yardstick_mean(truth - estimate, case_weights = case_weights)
 }
