@@ -6,7 +6,7 @@
 #' This is equivalent to `roc_auc(estimator = "macro_weighted")`.
 #'
 #' @family class probability metrics
-#' @templateVar metric_fn roc_aunp
+#' @templateVar fn roc_aunp
 #' @template return
 #' @template event_first
 #'
@@ -96,14 +96,12 @@ roc_aunp.data.frame <- function(data,
                                 options = list()) {
   check_roc_options_deprecated("roc_aunp", options)
 
-  estimate <- dots_to_estimate(data, !!! enquos(...))
-
-  metric_summarizer(
-    metric_nm = "roc_aunp",
-    metric_fn = roc_aunp_vec,
+  prob_metric_summarizer(
+    name = "roc_aunp",
+    fn = roc_aunp_vec,
     data = data,
     truth = !!enquo(truth),
-    estimate = !!estimate,
+    ...,
     estimator = NULL,
     na_rm = na_rm,
     event_level = NULL,
@@ -119,34 +117,31 @@ roc_aunp_vec <- function(truth,
                          case_weights = NULL,
                          options = list(),
                          ...) {
+  abort_if_class_pred(truth)
+
   check_roc_options_deprecated("roc_aunp_vec", options)
 
   estimator <- "macro_weighted"
 
-  # `event_level` doesn't really matter, but we set it anyways
-  roc_aunp_impl <- function(truth,
-                            estimate,
-                            ...,
-                            case_weights = NULL) {
-    check_dots_empty()
+  check_prob_metric(truth, estimate, case_weights, estimator)
 
-    roc_auc_vec(
-      truth = truth,
-      estimate = estimate,
-      estimator = estimator,
-      na_rm = FALSE,
-      event_level = "first",
-      case_weights = case_weights
-    )
+  if (na_rm) {
+    result <- yardstick_remove_missing(truth, estimate, case_weights)
+
+    truth <- result$truth
+    estimate <- result$estimate
+    case_weights <- result$case_weights
+  } else if (yardstick_any_missing(truth, estimate, case_weights)) {
+    return(NA_real_)
   }
 
-  metric_vec_template(
-    metric_impl = roc_aunp_impl,
+  # `event_level` doesn't really matter, but we set it anyways
+  roc_auc_vec(
     truth = truth,
     estimate = estimate,
     estimator = estimator,
-    na_rm = na_rm,
-    case_weights = case_weights,
-    cls = c("factor", "numeric")
+    na_rm = FALSE,
+    event_level = "first",
+    case_weights = case_weights
   )
 }
