@@ -58,6 +58,21 @@ test_that("two class with case weights is correct", {
   )
 })
 
+test_that("works with hardhat case weights", {
+  lst <- data_altman()
+  df <- lst$pathology
+  imp_wgt <- hardhat::importance_weights(seq_len(nrow(df)))
+  freq_wgt <- hardhat::frequency_weights(seq_len(nrow(df)))
+
+  expect_no_error(
+    accuracy_vec(df$pathology, df$scan, case_weights = imp_wgt)
+  )
+
+  expect_no_error(
+    accuracy_vec(df$pathology, df$scan, case_weights = freq_wgt)
+  ) 
+})
+
 test_that("work with class_pred input", {
   skip_if_not_installed("probably")
 
