@@ -17,6 +17,21 @@ test_that("Two class", {
   )
 })
 
+test_that("works with hardhat case weights", {
+  lst <- data_altman()
+  df <- lst$pathology
+  imp_wgt <- hardhat::importance_weights(seq_len(nrow(df)))
+  freq_wgt <- hardhat::frequency_weights(seq_len(nrow(df)))
+
+  expect_no_error(
+    bal_accuracy_vec(df$pathology, df$scan, case_weights = imp_wgt)
+  )
+
+  expect_no_error(
+    bal_accuracy_vec(df$pathology, df$scan, case_weights = freq_wgt)
+  ) 
+})
+
 test_that("`event_level = 'second'` should be identical to 'first'", {
   lst <- data_altman()
   pathology <- lst$pathology
