@@ -51,3 +51,19 @@ test_that("Weighted results are working", {
     3.5 / 4
   )
 })
+
+test_that("works with hardhat case weights", {
+  solubility_test$weights <- floor(read_weights_solubility_test())
+  df <- solubility_test
+
+  imp_wgt <- hardhat::importance_weights(df$weights)
+  freq_wgt <- hardhat::frequency_weights(df$weights)
+
+  expect_no_error(
+    huber_loss_vec(df$solubility, df$prediction, case_weights = imp_wgt)
+  )
+
+  expect_no_error(
+    huber_loss_vec(df$solubility, df$prediction, case_weights = freq_wgt)
+  ) 
+})
\ No newline at end of file
