@@ -36,3 +36,19 @@ test_that("weighted results are correct", {
     -4 / 3
   )
 })
+
+test_that("works with hardhat case weights", {
+  solubility_test$weights <- floor(read_weights_solubility_test())
+  df <- solubility_test
+
+  imp_wgt <- hardhat::importance_weights(df$weights)
+  freq_wgt <- hardhat::frequency_weights(df$weights)
+
+  expect_no_error(
+    msd_vec(df$solubility, df$prediction, case_weights = imp_wgt)
+  )
+
+  expect_no_error(
+    msd_vec(df$solubility, df$prediction, case_weights = freq_wgt)
+  ) 
+})
\ No newline at end of file
